==> huaweicloudsdkaad-3.1.86-py2.py3-none-any.whl: huaweicloudsdkaad/v1/model/update_package_ip_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdatePackageIpRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'protected_ip_list': 'list[UpdateProtectedIpInPolicyBody]'
    }

    attribute_map = {
        'protected_ip_list': 'protected_ip_list'
    }

    def __init__(self, protected_ip_list=None):
        """UpdatePackageIpRequestBody

        The model defined in huaweicloud sdk

        :param protected_ip_list: 全量防护ip列表
        :type protected_ip_list: list[:class:`huaweicloudsdkaad.v1.UpdateProtectedIpInPolicyBody`]
        """
        
        

        self._protected_ip_list = None
        self.discriminator = None

        self.protected_ip_list = protected_ip_list

    @property
    def protected_ip_list(self):
        """Gets the protected_ip_list of this UpdatePackageIpRequestBody.

        全量防护ip列表

        :return: The protected_ip_list of this UpdatePackageIpRequestBody.
        :rtype: list[:class:`huaweicloudsdkaad.v1.UpdateProtectedIpInPolicyBody`]
        """
        return self._protected_ip_list

    @protected_ip_list.setter
    def protected_ip_list(self, protected_ip_list):
        """Sets the protected_ip_list of this UpdatePackageIpRequestBody.

        全量防护ip列表

        :param protected_ip_list: The protected_ip_list of this UpdatePackageIpRequestBody.
        :type protected_ip_list: list[:class:`huaweicloudsdkaad.v1.UpdateProtectedIpInPolicyBody`]
        """
        self._protected_ip_list = protected_ip_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePackageIpRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaad-3.1.156-py2.py3-none-any.whl: huaweicloudsdkaad/v1/model/update_package_ip_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdatePackageIpRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'protected_ip_list': 'list[UpdateProtectedIpInPolicyBody]'
    }

    attribute_map = {
        'protected_ip_list': 'protected_ip_list'
    }

    def __init__(self, protected_ip_list=None):
        r"""UpdatePackageIpRequestBody

        The model defined in huaweicloud sdk

        :param protected_ip_list: 全量防护ip列表
        :type protected_ip_list: list[:class:`huaweicloudsdkaad.v1.UpdateProtectedIpInPolicyBody`]
        """
        
        

        self._protected_ip_list = None
        self.discriminator = None

        self.protected_ip_list = protected_ip_list

    @property
    def protected_ip_list(self):
        r"""Gets the protected_ip_list of this UpdatePackageIpRequestBody.

        全量防护ip列表

        :return: The protected_ip_list of this UpdatePackageIpRequestBody.
        :rtype: list[:class:`huaweicloudsdkaad.v1.UpdateProtectedIpInPolicyBody`]
        """
        return self._protected_ip_list

    @protected_ip_list.setter
    def protected_ip_list(self, protected_ip_list):
        r"""Sets the protected_ip_list of this UpdatePackageIpRequestBody.

        全量防护ip列表

        :param protected_ip_list: The protected_ip_list of this UpdatePackageIpRequestBody.
        :type protected_ip_list: list[:class:`huaweicloudsdkaad.v1.UpdateProtectedIpInPolicyBody`]
        """
        self._protected_ip_list = protected_ip_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePackageIpRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
